<!DOCTYPE html>
<html>
<head>
<meta charset="UTF-8">
<meta name="viewport" content="width=device-width, initial-scale=1.0">
<title>Php Advanced Search Example</title>
</head>
<body>

<?php
/* Validate and assign input data */
/* Note that, in this example, both model and colour are allowed to be empty */
$model = filter_input(INPUT_POST, "model", FILTER_SANITIZE_STRING);
$colour = filter_input(INPUT_POST, "colour", FILTER_SANITIZE_STRING);



/* Include "configuration.php" file */
require_once "configuration.php";



/* Connect to the database */
$dbConnection = new PDO("mysql:host=$dbHost;dbname=$dbName", $dbUsername, $dbPassword);
$dbConnection->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);   // set the PDO error mode to exception



/* Perform Query */
if (empty($model) && empty($colour))
{
    $query = "SELECT id, model, colour, year, price FROM toyota";
    $statement = $dbConnection->prepare($query);
}
else
{
    if (empty($model)) // colour is not empty
    {
        $query = "SELECT id, model, colour, year, price FROM toyota WHERE colour = :colour";
        $statement = $dbConnection->prepare($query);
        $statement->bindParam(":colour", $colour, PDO::PARAM_STR);
    }
    else if (empty($colour)) // model is not empty
    {
        $query = "SELECT id, model, colour, year, price FROM toyota WHERE model = :model";
        $statement = $dbConnection->prepare($query);
        $statement->bindParam(":model", $model, PDO::PARAM_STR);
    }
    else
    {
        $query = "SELECT id, model, colour, year, price FROM toyota WHERE model = :model AND colour = :colour";
        $statement = $dbConnection->prepare($query);
        $statement->bindParam(":model", $model, PDO::PARAM_STR);
        $statement->bindParam(":colour", $colour, PDO::PARAM_STR);
    }
}
$statement->execute();



/* Manipulate the query result */
if ($statement->rowCount() > 0)
{
    echo "<table>";
    $result = $statement->fetchAll(PDO::FETCH_OBJ);
    foreach ($result as $row)
    {
        echo "<tr>";
        echo "<td>" . $row->model . "</td><td>" . $row->colour . "</td><td>" . $row->year . "</td><td>" . $row->price . "</td><td>" . $row->id . "</td>";
        echo "</tr>";
    }
    echo "</table>";
}
echo "<p>" . $statement->rowCount() . " records found.</p>";



/* Provide a link for the user to proceed to a new webpage or automatically redirect to a new webpage */
echo "<a href='search_colour_and_model.php'>Perform another search</a>";
?>        
</body>
</html>